#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end

#' Foundations and Applications of Statistics
#' 
#' Data sets and utility functions to accompany \cite{Foundations and
#' Applications of Statistics: An Introduction Using R} by Randall Pruim.
#' 
#' @name fastR2-package
#' @aliases fastR
#' @author Randall Pruim
#' 
#' Maintainer: Randall Pruim <rpruim@@calvin.edu>
#' @references R. Pruim, \cite{Foundations and Applicaitons of Statistics: An Introduction Using R}, AMS, 2011.
#' @keywords package 
#' @examples
#' 
#' require(fastR2)
#' trellis.par.set(theme=col.fastR())
#' 

#' @import mosaic
#' @importFrom stats coef df qnorm
"_PACKAGE"


